@@ -1,5 +1,5 @@
 /*  This file is part of GNU cflow
- *  Copyright (C) 1997, 2007, 2010 Sergey Poznyakoff
+ *  Copyright (C) 1997-2025 Sergey Poznyakoff
  *  
  *  GNU cflow is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -12,30 +12,31 @@
  *  GNU General Public License for more details.
  *  
  *  You should have received a copy of the GNU General Public License
- *  along with GNU cflow; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- *  MA 02110-1301 USA
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 /* tokens */
-#define WORD 257
-#define LBRACE0 258
-#define RBRACE0 259
-#define IDENTIFIER 260
-#define EXTERN 261
-#define STATIC 262
-#define TYPEDEF 263
-#define STRUCT 264
-#define MODIFIER 265
-#define OP 266
-#define UNION 267
-#define ENUM 268
-#define LBRACE '{'
-#define RBRACE '}'
-#define MEMBER_OF 269
-#define TYPE 270
-#define STRING 271
-#define PARM_WRAPPER 272
-#define QUALIFIER 273
+enum {
+     LBRACE = '{',
+     RBRACE = '}',
+     WORD = 257,
+     LBRACE0,
+     RBRACE0,
+     IDENTIFIER,
+     EXTERN,
+     STATIC,
+     TYPEDEF,
+     STRUCT,
+     MODIFIER,
+     OP,
+     UNION,
+     ENUM,
+     MEMBER_OF,
+     TYPE,
+     STRING,
+     PARM_WRAPPER,
+     QUALIFIER,
+     DECLARATION
+};
 
 typedef struct {
     char *str;
